@@ -1,12 +1,13 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <signal.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <linux/major.h>
-#include <scsi/scsi_ioctl.h>
 
+#define SCSI_IOCTL_START_STOP 8			/* Start or stop unit */
 
 #define SD_IOCTL_IDLE 4746	/* get idle time */
 
@@ -22,7 +23,6 @@ void handler()
 
 int main(int argc, char *argv[])
 {
-  int result;
   int fd;
   struct stat statbuf;
 
@@ -50,7 +50,7 @@ int main(int argc, char *argv[])
   }
 
   if (!S_ISBLK(statbuf.st_mode)
-      || (statbuf.st_rdev >> 8) & 255 != SCSI_DISK_MAJOR)
+      || ( (statbuf.st_rdev >> 8) & (255 != SCSI_DISK_MAJOR) ) )
   {
     fprintf(stderr, "%s is not a SCSI block device\n", argv[1]);
     close(fd);
@@ -72,7 +72,7 @@ int main(int argc, char *argv[])
     if (last == 0)
       printf("%s has not been accessed\n", argv[1]);
     else
-      printf("%s has been idle for %d second%s\n", argv[1],
+      printf("%s has been idle for %ld second%s\n", argv[1],
 	     last, (last==1 ? "":"s"));
   }
   else
@@ -92,7 +92,7 @@ int main(int argc, char *argv[])
 
       /* Spin down disk immediately */
 
-      if (ioctl(fd, SCSI_IOCTL_STOP_UNIT) < 0)
+      if (ioctl(fd, SCSI_IOCTL_START_STOP, &off) < 0)
       {
 	perror(argv[1]);
 	close(fd);
@@ -117,7 +117,7 @@ int main(int argc, char *argv[])
 
       if ((fp = fopen(lockfn, "r")) != NULL)
       {
-	fscanf(fp, "%ld", &pid);
+	fscanf(fp, "%d", &pid);
 	fclose(fp);
 
 	kill(pid, SIGTERM);
@@ -142,7 +142,7 @@ int main(int argc, char *argv[])
 	  close(fd);
 	  exit(1);
 	}
-	fprintf(fp, "%ld\n", getpid());
+	fprintf(fp, "%d\n", getpid());
 	fclose(fp);
 
 #if 1
@@ -167,7 +167,9 @@ int main(int argc, char *argv[])
 	  
 	  if (last > timeout)
 	  {
-	    if (ioctl(fd, SCSI_IOCTL_STOP_UNIT) != 0)
+	    long off = 0;
+	    
+	    if (ioctl(fd, SCSI_IOCTL_START_STOP, &off) != 0)
 	    {
 	      perror(argv[1]);
 	      close(fd);
